@@ -7,6 +7,7 @@ Module that contains classes to handle version files
 
 import getpass
 
+from tpDcc.libs import python
 from tpDcc.libs.python import folder, path, fileio, sort, name as name_utils
 
 
@@ -242,7 +243,7 @@ class VersionFile(object):
         if file_name:
             self._save(file_name)
         else:
-            print('Could not save default version!')
+            python.logger.warning('Could not save default version!')
 
         return file_name
 
@@ -267,7 +268,7 @@ class VersionFile(object):
         version_folder = self._get_version_folder()
         version_files = folder.get_files_and_folders(version_folder)
         if not version_files:
-            print('WARNING: Impossible to get versions because no version exist!')
+            python.logger.warning('Impossible to get versions because no version exist!')
             return None
 
         number_list = list()
@@ -284,7 +285,7 @@ class VersionFile(object):
             pass_files.append(f)
 
         if not pass_files:
-            print('WARNING: No valid version files found in folder: {}'.format(version_folder))
+            python.logger.warning('No valid version files found in folder: {}'.format(version_folder))
             return
 
         quick_sort = sort.QuickNumbersListSort(number_list)
@@ -309,7 +310,7 @@ class VersionFile(object):
         version_folder = self._get_version_folder()
         version_files = folder.get_files_and_folders(version_folder)
         if not version_files:
-            print('WARNING: Impossible to get version numbers because no version exist!')
+            python.logger.warning('Impossible to get version numbers because no version exist!')
             return None
 
         number_list = list()
@@ -385,11 +386,11 @@ class VersionFile(object):
         if path.is_file(comment_path):
             read = fileio.FileReader(comment_path)
             lines = read.read()
-            for l in lines:
+            for line in lines:
                 line_info_dict = dict()
                 user = None
                 comment = None
-                split_line = l.split(';')
+                split_line = line.split(';')
                 for sub_line in split_line:
                     assign = sub_line.split('=')
                     if assign and assign[0]:
